﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Net.Http;
using System.Text;
using ELTE.TodoList.Desktop.Model;
using ELTE.TodoList.Persistence.DTO;

namespace ELTE.TodoList.Desktop.ViewModel
{
    public class MainViewModel : ViewModelBase
    {
        private readonly TodoListApiService _service;
        private ObservableCollection<ListDto> _lists;

        public ObservableCollection<ListDto> Lists
        {
            get { return _lists; }
            set { _lists = value; OnPropertyChanged(); }
        }

        private ObservableCollection<ItemDto> _items;   

        public ObservableCollection<ItemDto> Items
        {
            get { return _items; }
            set { _items = value; OnPropertyChanged(); }
        }

        public DelegateCommand RefreshListsCommand { get; private set; }
        public DelegateCommand SelectCommand { get; private set; }

        public MainViewModel(TodoListApiService service)
        {
            _service = service;

            RefreshListsCommand = new DelegateCommand(_ => LoadListsAsync());
            SelectCommand = new DelegateCommand(param => LoadItemsAsync(param as ListDto));
        }

        private async void LoadListsAsync()
        {
            try
            {
                Lists = new ObservableCollection<ListDto>(await _service.LoadListsAsync());
            }
            catch (Exception ex) when (ex is NetworkException || ex is HttpRequestException)
            {
                OnMessageApplication($"Unexpected error occured! ({ex.Message})");
            }
        }
        private async void LoadItemsAsync(ListDto listDto)
        {
            if (listDto is null)
                return;

            try
            {
                Items = new ObservableCollection<ItemDto>(await _service.LoadItemsAsync(listDto.Id));
            }
            catch (Exception ex) when (ex is NetworkException || ex is HttpRequestException)
            {
                OnMessageApplication($"Unexpected error occured! ({ex.Message})");
            }
        }
    }
}
